"""
    OneSignal

    A powerful way to send personalized messages at scale and build effective customer engagement strategies. Learn more at onesignal.com  # noqa: E501

    The version of the OpenAPI document: 1.0.1
    Contact: devrel@onesignal.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import onesignal
from onesignal.model.basic_notification import BasicNotification
from onesignal.model.basic_notification_all_of_android_background_layout import BasicNotificationAllOfAndroidBackgroundLayout
from onesignal.model.button import Button
from onesignal.model.notification_all_of import NotificationAllOf
from onesignal.model.string_map import StringMap
globals()['BasicNotification'] = BasicNotification
globals()['BasicNotificationAllOfAndroidBackgroundLayout'] = BasicNotificationAllOfAndroidBackgroundLayout
globals()['Button'] = Button
globals()['NotificationAllOf'] = NotificationAllOf
globals()['StringMap'] = StringMap
from onesignal.model.notification import Notification


class TestNotification(unittest.TestCase):
    """Notification unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNotification(self):
        """Test Notification"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Notification()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
