"""
    OneSignal

    A powerful way to send personalized messages at scale and build effective customer engagement strategies. Learn more at onesignal.com  # noqa: E501

    The version of the OpenAPI document: 1.0.1
    Contact: devrel@onesignal.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import onesignal
from onesignal.model.delete_player_success_response import DeletePlayerSuccessResponse


class TestDeletePlayerSuccessResponse(unittest.TestCase):
    """DeletePlayerSuccessResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeletePlayerSuccessResponse(self):
        """Test DeletePlayerSuccessResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeletePlayerSuccessResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
